@@ -47,7 +47,7 @@ def unregister(model_or_iterable, fail_silently=False):
     Remove one or more models from the autofixture registry.
     '''
     from django.db import models
-    if isinstance(model_or_iterable, (list, tuple, set)):
+    if issubclass(model_or_iterable, models.Model):
         model_or_iterable = [model_or_iterable]
     for model in models:
         if isinstance(model, basestring):
@@ -76,7 +76,7 @@ def create(model, count, *args, **kwargs):
     superusers::
 
         import autofixture
-        admins = autofixture('auth.User', 10, field_values={'is_superuser': True})
+        admins = autofixture.create('auth.User', 10, field_values={'is_superuser': True})
 
     .. note:: See :ref:`AutoFixture` for more information.
 
