@@ -4,6 +4,7 @@ from django.db.models import fields
 from django.db.models.fields import related
 from django.utils.datastructures import SortedDict
 from autofixture import constraints, generators, signals
+from autofixture.values import Values
 
 
 class CreateInstanceError(Exception):
@@ -58,7 +59,18 @@ class Link(object):
         return Link(fields, default=self.default)
 
 
-class AutoFixture(object):
+class AutoFixtureMetaclass(type):
+    def __new__(mcs, name, bases, attrs):
+        values = Values()
+        for base in bases[::-1]:
+            values += base.field_values
+        values += Values(attrs.pop('Values', {}))
+        values += attrs.get('field_values', Values())
+        attrs['field_values'] = values
+        return super(AutoFixtureMetaclass, mcs).__new__(mcs, name, bases, attrs)
+
+
+class AutoFixtureBase(object):
     '''
     .. We don't support the following fields yet:
 
@@ -71,16 +83,13 @@ class AutoFixture(object):
     class IGNORE_FIELD(object):
         pass
 
-    class Values(object):
-        pass
-
     overwrite_defaults = False
     follow_fk = True
     generate_fk = False
     follow_m2m = {'ALL': (1,5)}
     generate_m2m = False
 
-    none_chance = 0.2
+    none_p = 0.2
     tries = 1000
 
     field_to_generator = SortedDict((
@@ -92,19 +101,20 @@ class AutoFixture(object):
         (fields.PositiveIntegerField, generators.PositiveIntegerGenerator),
         (fields.SmallIntegerField, generators.SmallIntegerGenerator),
         (fields.IntegerField, generators.IntegerGenerator),
+        (fields.FloatField, generators.FloatGenerator),
         (fields.IPAddressField, generators.IPAddressGenerator),
         (fields.TextField, generators.LoremGenerator),
         (fields.TimeField, generators.TimeGenerator),
     ))
 
-    field_values = {}
+    field_values = Values()
 
     default_constraints = [
         constraints.unique_constraint,
         constraints.unique_together_constraint]
 
     def __init__(self, model,
-            field_values=None, none_chance=None, overwrite_defaults=None,
+            field_values=None, none_p=None, overwrite_defaults=None,
             constraints=None, follow_fk=None, generate_fk=None,
             follow_m2m=None, generate_m2m=None):
         '''
@@ -116,7 +126,7 @@ class AutoFixture(object):
             a ``Generator`` instance that generates a value on the fly or a
             callable which takes no arguments and returns the wanted value.
 
-            ``none_chance``: The chance (between 0 and 1, 1 equals 100%) to
+            ``none_p``: The chance (between 0 and 1, 1 equals 100%) to
             assign ``None`` to nullable fields.
 
             ``overwrite_defaults``: All default values of fields are preserved
@@ -149,14 +159,11 @@ class AutoFixture(object):
             will be ignored if this parameter is set.
         '''
         self.model = model
-        self.field_values = dict((
-            (k,v) for k,v in self.Values.__dict__.items()
-            if k[:2] != '__' and k[-2:] != '__' and not k.startswith('_Values__')))
-        self.field_values.update(self.__class__.field_values.copy())
-        self.field_values.update(field_values or {})
+        self.field_values = Values(self.__class__.field_values)
+        self.field_values += Values(field_values)
         self.constraints = constraints or []
-        if none_chance is not None:
-            self.none_chance = none_chance
+        if none_p is not None:
+            self.none_p = none_p
         if overwrite_defaults is not None:
             self.overwrite_defaults = overwrite_defaults
 
@@ -206,8 +213,9 @@ class AutoFixture(object):
 
     def add_field_value(self, name, value):
         '''
-        Pass a static *value* that should be assigned to the field called
-        *name*. *value* may be a :ref:`Generator <Generator>` instance.
+        Pass a *value* that should be assigned to the field called *name*.
+        Thats the same as specifying it in the *field_values* argument of the
+        :meth:`constructor <autofixture.base.AutoFixture.__init__>`.
         '''
         self.field_values[name] = value
 
@@ -242,7 +250,7 @@ class AutoFixture(object):
             return generators.StaticGenerator(value=value)
 
         if field.null:
-            kwargs['none_chance'] = self.none_chance
+            kwargs['empty_p'] = self.none_p
         if field.choices:
             return generators.ChoicesGenerator(choices=field.choices, **kwargs)
         if isinstance(field, related.ForeignKey):
@@ -356,20 +364,9 @@ class AutoFixture(object):
     def process_m2m(self, instance, field):
         # check django's version number to determine how intermediary models
         # are checked if they are auto created or not.
-        from django import VERSION
         auto_created_through_model = False
         through = field.rel.through
-        if VERSION < (1,2):
-            if through:
-                if isinstance(through, basestring):
-                    bits = through.split('.')
-                    if len(bits) < 2:
-                        bits = [instance._meta.app_label] + bits
-                    through = models.get_model(*bits)
-            else:
-                auto_created_through_model = True
-        else:
-            auto_created_through_model = through._meta.auto_created
+        auto_created_through_model = through._meta.auto_created
 
         if auto_created_through_model:
             return self.process_field(instance, field)
@@ -485,3 +482,7 @@ class AutoFixture(object):
 
     def __iter__(self):
         yield self.create_one()
+
+
+class AutoFixture(AutoFixtureBase):
+    __metaclass__ = AutoFixtureMetaclass
